pub fn push_style_var_imvec2(element: &StyleVar, value: ImVec2) -> StyleVarTokenExpand description
Push an ImVec2 style variable to the stack. The returned token is used for removing the variable from the stack again.
pub fn push_style_var_imvec2(element: &StyleVar, value: ImVec2) -> StyleVarTokenPush an ImVec2 style variable to the stack. The returned token is used for removing the variable from the stack again.